/* Bickel, P.J. and Doksum, K.A. 1977
 * Mathematical Statistics:
 * Basic Ideas and Selected Topics
 * Holden-Day: Oakland. 493.pp.
 * Example pp. 95 - 97.
 */
#include <dap.h>

void main()
{
  infile("ms95.dat", " ")
    {
      double soilphos, plantphos;
      input("soilphos plantphos");
      outset("ms95", "");
      skip(1);
      while (step())
        output();
    }

  nport(plotlinreg("ms95", "plantphos", "soilphos", "==", "", 1, 0.95), 4, 4);
}
